/* ---------------------------------------------------------------------- *
 * modules.h
 * This file is part of lincity.
 * Lincity is copyright (c) I J Peters 1995-1997, (c) Greg Sharp 1997-2001.
 * (c) Corey Keasling, 2004
 * ---------------------------------------------------------------------- */
#ifndef __modules_h__
#define __modules_h__

#include "../lctypes.h"
#include "tinygettext/gettext.hpp"
#include "../engglobs.h"
#include "../engine.h"
#include "../stats.h"
#include "gui_interface/mps.h"
#include "../lclib.h"

#include "market.h"
#include "../power.h"

// for real_time
//#include "cliglobs.h"

#endif /* __modules_h__ */
